@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: ar.h,v 1.24 2004/09/08 20:19:07 pinto Exp $
+ $Id: ar.h 443809 2005-08-07 13:26:03Z fedemar $
 
  ark -- archiver for the KDE project
 
@@ -52,8 +52,7 @@ public:
   virtual void addDir(const QString &) {} // never gets called
 
   virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="",
-			  bool viewFriendly=false);
+  virtual void unarchFileInternal();
 
 private:
   void setHeaders();
