@@ -58,7 +58,7 @@ keyServer::keyServer(QWidget *parent, const char *name,bool modal,bool autoClose
 	config=new KSimpleConfig ("kgpgrc");
 	page=new keyServerWidget();
 	setMainWidget(page);
-	
+
         syncCombobox();
         page->kLEimportid->setFocus();
 
@@ -165,20 +165,20 @@ void keyServer::slotSearch()
         }
 
         //listpop = new KeyServer( this,"result",WType_Dialog | WShowModal);
-	
+
 	dialogServer=new KDialogBase(KDialogBase::Swallow, i18n("Import Key From Keyserver"),  KDialogBase::Ok | KDialogBase::Close,KDialogBase::Ok,this,0,true);
-	
+
 	dialogServer->setButtonText(KDialogBase::Ok,i18n("&Import"));
 	dialogServer->enableButtonOK(false);
 	listpop=new searchRes();
-        //listpop->setMinimumWidth(250);
-        //listpop->adjustSize();
-        listpop->statusText->setText(i18n("Connecting to the server..."));   
-        
+	listpop->kLVsearch->setColumnWidthMode(0,QListView::Manual);
+	listpop->kLVsearch->setColumnWidthMode(1,QListView::Manual);
+	listpop->kLVsearch->setColumnWidth(0,150);
+	listpop->kLVsearch->setColumnWidth(1,130);
+        listpop->statusText->setText(i18n("Connecting to the server..."));
         connect(listpop->kLVsearch,SIGNAL(selectionChanged()),this,SLOT(transferKeyID()));
         connect(dialogServer,SIGNAL(okClicked()),this,SLOT(preimport()));
         connect(listpop->kLVsearch,SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),dialogServer,SIGNAL(okClicked()));
-        //connect(listpop->kLVsearch,SIGNAL(returnPressed ( QListViewItem * )),this,SLOT(preimport()));
 
         connect(dialogServer,SIGNAL(closeClicked()),this,SLOT(handleQuit()));
         connect( listpop , SIGNAL( destroyed() ) , this, SLOT( abortSearch()));
@@ -202,12 +202,13 @@ void keyServer::slotSearch()
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 	dialogServer->setMainWidget(listpop);
 	listpop->setMinimumSize(listpop->sizeHint());
+	listpop->setMinimumWidth(550);
         dialogServer->exec();
 }
 
 void keyServer::handleQuit()
 {
-	if (searchproc->isRunning()) 
+	if (searchproc->isRunning())
 	{
 	    QApplication::restoreOverrideCursor();
 	    disconnect(searchproc,0,0,0);
@@ -219,7 +220,6 @@ void keyServer::handleQuit()
 
 void keyServer::abortSearch()
 {
-
         if (dialogServer) {
                 delete dialogServer;
                 dialogServer=0L;
@@ -245,22 +245,13 @@ void keyServer::transferKeyID()
         QString kid,keysToSearch;
 	listpop->kLEID->clear();
 	QPtrList< QListViewItem >searchList=listpop->kLVsearch->selectedItems();
-	
+
 	for ( uint i = 0; i < searchList.count(); ++i )
 	{
                 if ( searchList.at(i) )
-		{
-                    if (searchList.at(i)->depth()==0)
-                	kid=searchList.at(i)->firstChild()->text(0).stripWhiteSpace();
-        		else
-                	kid=searchList.at(i)->text(0).stripWhiteSpace();
-		//
-        	kid=kid.section("key",1,1);
-        	kid=kid.stripWhiteSpace();
-		keysToSearch.append(" "+kid.left(8));
-		}
+		keysToSearch.append(" "+searchList.at(i)->text(3));
 	}
-	kdDebug(2100)<<keysToSearch<<endl;
+//	kdDebug(2100)<<keysToSearch<<endl;
 	listpop->kLEID->setText(keysToSearch.stripWhiteSpace());
 }
 
@@ -275,6 +266,7 @@ void keyServer::slotsearchresult(KProcess *)
 
         if (listpop->kLVsearch->firstChild()!=NULL) {
                 listpop->kLVsearch->setSelected(listpop->kLVsearch->firstChild(),true);
+		listpop->kLVsearch->setCurrentItem(listpop->kLVsearch->firstChild());
                 transferKeyID();
         }
 }
@@ -282,6 +274,7 @@ void keyServer::slotsearchresult(KProcess *)
 void keyServer::slotsearchread(KProcIO *p)
 {
         QString required;
+	QString keymail,keyname;
         while (p->readln(required,true)!=-1) {
                 //required=QString::fromUtf8(required);
 
@@ -300,22 +293,49 @@ void keyServer::slotsearchread(KProcIO *p)
                         required=QString::null;
                 }
 
-                if ((cycle) && (!required.isEmpty())) {
-                        QString kid=required.stripWhiteSpace();
-                        (void) new KListViewItem(kitem,kid);
-                        kid=kid.section("key",1,1);
-                        kid=kid.stripWhiteSpace();
-                        kid=kid.left(8);
+                if (required.find("(")==0) {
+                        cycle=true;
+			QString fullname=required.remove(0,required.find(")")+1).stripWhiteSpace();
+			if (fullname.find("<")!=-1) {
+	                keymail=fullname.section('<',-1,-1);
+			if (keymail.endsWith(">")) keymail.truncate(keymail.length()-1);
+                	keyname=fullname.section('<',0,0);
+        		} else {
+                	keymail=QString::null;
+			keyname=fullname;
+		        }
+                        kitem=new KListViewItem(listpop->kLVsearch,keyname,keymail,QString::null,QString::null);
+                        keyNumbers++;
+                        count=0;
                         required=QString::null;
                 }
 
-                cycle=false;
-
-                if ((required.find("(")!=-1) && (!required.isEmpty())) {
-                        cycle=true;
-                        kitem=new KListViewItem(listpop->kLVsearch,required.remove(0,required.find(")")+1).stripWhiteSpace());
-                        keyNumbers++;
-                        count=0;
+                if ((cycle) && (!required.isEmpty())) {
+                        QString subkey=required.stripWhiteSpace();
+			if (subkey.find(" key ")!=-1 && subkey.at(0).isDigit ())
+			{
+                        QString kid=subkey.section(" key ",1,1);
+                        kid=kid.stripWhiteSpace();
+                        kid=kid.left(8);
+			kitem->setText(3,kid);
+			QString creation=subkey.section("created",1,1);
+			if (creation.startsWith(":")) creation=creation.right(creation.length()-1);
+			kitem->setText(2,creation);
+			cycle=false;
+			}
+			else 
+			{
+			if (subkey.find("<")!=-1) {
+	                keymail=subkey.section('<',-1,-1);
+        	        if (keymail.endsWith(">")) keymail.truncate(keymail.length()-1);
+                	keyname=subkey.section('<',0,0);
+        		} else {
+                	keymail=QString::null;
+			keyname=subkey;
+		        }
+			KListViewItem *subk = new KListViewItem(kitem,keyname,keymail,QString::null,QString::null);
+			subk->setSelectable(false);
+			}
                         required=QString::null;
                 }
         }
@@ -337,7 +357,7 @@ void keyServer::slotExport(QString keyId)
         *exportproc<<"gpg";
 	if (!page->exportAttributes->isChecked())
                 *exportproc<<"--export-options"<<"no-include-attributes";
-	
+
         if (page->cBproxyE->isChecked()) {
                 exportproc->setEnvironment("http_proxy",page->kLEproxyE->text());
                 *exportproc<<	"--keyserver-options"<<"honor-http-proxy";
@@ -349,7 +369,7 @@ void keyServer::slotExport(QString keyId)
         QObject::connect(exportproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotimportread(KProcIO *)));
         exportproc->start(KProcess::NotifyOnExit,true);
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
-        importpop = new QDialog( this,0,true);
+        importpop = new QDialog( this,0,true,Qt::WDestructiveClose);
         QVBoxLayout *vbox=new QVBoxLayout(importpop,3);
         QLabel *tex=new QLabel(importpop);
         tex->setText(i18n("<b>Connecting to the server...</b>"));
@@ -359,15 +379,14 @@ void keyServer::slotExport(QString keyId)
         importpop->setMinimumWidth(250);
         importpop->adjustSize();
         importpop->show();
-        connect(Buttonabort,SIGNAL(clicked ()),this,SLOT(abortExport()));
+        connect(importpop,SIGNAL(destroyed ()),this,SLOT(abortExport()));
+	connect(Buttonabort,SIGNAL(clicked ()),importpop,SLOT(close()));
 }
 
 void keyServer::abortExport()
 {
 	QApplication::restoreOverrideCursor();
-        if (importpop)
-                delete importpop;
-        if (exportproc->isRunning()) 
+        if (exportproc->isRunning())
 	{
 	    disconnect(exportproc,0,0,0);
 	    exportproc->kill();
@@ -394,7 +413,7 @@ void keyServer::slotImport()
         readmessage=QString::null;
         importproc=new KProcIO();
         QString keyserv=page->kCBimportks->currentText();
-
+	
         *importproc<<"gpg";
         if (page->cBproxyI->isChecked()) {
                 importproc->setEnvironment("http_proxy",page->kLEproxyI->text());
@@ -413,12 +432,12 @@ void keyServer::slotImport()
                 *importproc<<QFile::encodeName(fkeyNames);
         }
 
-
         QObject::connect(importproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotimportresult(KProcess *)));
         QObject::connect(importproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotimportread(KProcIO *)));
         importproc->start(KProcess::NotifyOnExit,true);
+	importproc->closeWhenDone();
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
-        importpop = new QDialog( this,0,true);
+        importpop = new QDialog( this,0,true,Qt::WDestructiveClose);
         QVBoxLayout *vbox=new QVBoxLayout(importpop,3);
         QLabel *tex=new QLabel(importpop);
         tex->setText(i18n("<b>Connecting to the server...</b>"));
@@ -428,19 +447,18 @@ void keyServer::slotImport()
         importpop->setMinimumWidth(250);
         importpop->adjustSize();
         importpop->show();
-        connect(Buttonabort,SIGNAL(clicked()),this,SLOT(abortImport()));
+	connect(Buttonabort,SIGNAL(clicked()),importpop,SLOT(close()));
+	connect(importpop,SIGNAL(destroyed ()),this,SLOT(abortImport()));
 }
 
 void keyServer::abortImport()
 {
 	QApplication::restoreOverrideCursor();
-        if (importpop)
-                delete importpop;
-	if (importproc->isRunning()) 
+	if (importproc->isRunning())
 	{
 	    disconnect(importproc,0,0,0);
+	    importproc->kill();
 	    emit importFinished(QString::null);
-	    importproc->kill();   
 	}
 	if (autoCloseWindow) close();
 }
@@ -476,41 +494,41 @@ void keyServer::slotimportresult(KProcess*)
 		importedNbSec=importedNb.section(" ",10,10);
 		dupNbSec=importedNb.section(" ",11,11);
 		notImportesNbSec=importedNb.section(" ",12,12);
-                resultMessage=i18n("<qt>%1 key(s) processed.<br></qt>").arg(importedNbProcess);
+                resultMessage=i18n("<qt>%n key processed.<br></qt>","<qt>%n keys processed.<br></qt>",importedNbProcess.toULong());
 		if (importedNbUnchanged!="0")
-		resultMessage+=i18n("<qt>%1 key(s) unchanged.<br></qt>").arg(importedNbUnchanged);
+		resultMessage+=i18n("<qt>One key unchanged.<br></qt>","<qt>%n keys unchanged.<br></qt>",importedNbUnchanged.toULong());
 		if (importedNbSig!="0")
-		resultMessage+=i18n("<qt>%1 signature(s) imported.<br></qt>").arg(importedNbSig);
+		resultMessage+=i18n("<qt>One signature imported.<br></qt>","<qt>%n signatures imported.<br></qt>",importedNbSig.toULong());
 		if (importedNbMissing!="0")
-		resultMessage+=i18n("<qt>%1 key(s) without ID.<br></qt>").arg(importedNbMissing);
+		resultMessage+=i18n("<qt>One key without ID.<br></qt>","<qt>%n keys without ID.<br></qt>",importedNbMissing.toULong());
 		if (importedNbRSA!="0")
-		resultMessage+=i18n("<qt>%1 RSA key(s) imported.<br></qt>").arg(importedNbRSA);
+		resultMessage+=i18n("<qt>One RSA key imported.<br></qt>","<qt>%n RSA keys imported.<br></qt>",importedNbRSA.toULong());
 		if (importedNbUid!="0")
-		resultMessage+=i18n("<qt>%1 user ID(s) imported.<br></qt>").arg(importedNbUid);
+		resultMessage+=i18n("<qt>One user ID imported.<br></qt>","<qt>%n user IDs imported.<br></qt>",importedNbUid.toULong());
 		if (importedNbSub!="0")
-		resultMessage+=i18n("<qt>%1 subkey(s) imported.<br></qt>").arg(importedNbSub);
+		resultMessage+=i18n("<qt>One subkey imported.<br></qt>","<qt>%n subkeys imported.<br></qt>",importedNbSub.toULong());
 		if (importedNbRev!="0")
-		resultMessage+=i18n("<qt>%1 revocation certificate(s) imported.<br></qt>").arg(importedNbRev);
+		resultMessage+=i18n("<qt>One revocation certificate imported.<br></qt>","<qt>%n revocation certificates imported.<br></qt>",importedNbRev.toULong());
 		if (readNbSec!="0")
-		resultMessage+=i18n("<qt>%1 secret key(s) processed.<br></qt>").arg(readNbSec);
+		resultMessage+=i18n("<qt>One secret key processed.<br></qt>","<qt>%n secret keys processed.<br></qt>",readNbSec.toULong());
 		if (importedNbSec!="0")
-		resultMessage+=i18n("<qt><b>%1 secret key(s) imported.</b><br></qt>").arg(importedNbSec);
+		resultMessage+=i18n("<qt><b>One secret key imported.</b><br></qt>","<qt><b>%n secret keys imported.</b><br></qt>",importedNbSec.toULong());
 		if (dupNbSec!="0")
-		resultMessage+=i18n("<qt>%1 secret key(s) unchanged.<br></qt>").arg(dupNbSec);
+		resultMessage+=i18n("<qt>One secret key unchanged.<br></qt>","<qt>%n secret keys unchanged.<br></qt>",dupNbSec.toULong());
 		if (notImportesNbSec!="0")
-		resultMessage+=i18n("<qt>%1 secret key(s) not imported.<br></qt>").arg(notImportesNbSec);
+		resultMessage+=i18n("<qt>One secret key not imported.<br></qt>","<qt>%n secret keys not imported.<br></qt>",notImportesNbSec.toULong());
 		if (importedNbSucess!="0")
-		resultMessage+=i18n("<qt><b>%1 key(s) imported:</b><br></qt>").arg(importedNbSucess);
+		resultMessage+=i18n("<qt><b>One key imported:</b><br></qt>","<qt><b>%n keys imported:</b><br></qt>",importedNbSucess.toULong());
         } else
                 resultMessage=i18n("No key imported... \nCheck detailed log for more infos");
-		
+
 	QString lastID=QString("0x"+importedKeys.last().section(" ",0,0).right(8));
-	if (!lastID.isEmpty()) 
+	if (!lastID.isEmpty())
 	{
-	//kdDebug(2100)<<"++++++++++imported key"<<lastID<<endl;	
+	//kdDebug(2100)<<"++++++++++imported key"<<lastID<<endl;
 	emit importFinished(lastID);
 	}
-	
+
         if (importpop)
                 importpop->hide();
 	(void) new KDetailedInfo(0,"import_result",resultMessage,readmessage,importedKeys);
@@ -531,20 +549,20 @@ void keyServer::syncCombobox()
 {
         config->setGroup("Servers");
         QString serverList=config->readEntry("Server_List");
-	
+
         QString optionsServer=KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
-        
+
 	//if (optionsServer.isEmpty())
 	//	optionsServer="hkp://wwwkeys.pgp.net";
 	page->kCBexportks->clear();
 	page->kCBimportks->clear();
-	
+
 	page->kCBexportks->insertItem(optionsServer);
         page->kCBimportks->insertItem(optionsServer);
-	
+
 	page->kCBexportks->insertStringList(QStringList::split(",",serverList));
 	page->kCBimportks->insertStringList(QStringList::split(",",serverList));
-        
+
 }
 
 void keyServer::slotOk()
