@@ -679,8 +679,8 @@ void CReplaceDialog::slotOk( void )
 CReplacePromptDialog::CReplacePromptDialog( QWidget *parent, const char *name,
 					     bool modal )
   :KDialogBase( Plain, i18n("Find & Replace"), User3|User2|User1|Close,
-		User2, parent, name, modal, true, i18n("&All"),
-		KStdGuiItem::no(), KStdGuiItem::yes() )
+		User2, parent, name, modal, true, i18n("Replace &All"),
+		i18n("Do Not Replace"), i18n("Replace"))
 {
   QString text;
   QBoxLayout *topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
@@ -1325,8 +1325,8 @@ bool verifyFileDestnation( QWidget *parent, const QString &title,
     QString msg = i18n( ""
       "You have specified an existing file.\n"
       "Overwrite current file?" );
-    int reply = KMessageBox::warningYesNo( parent, msg, title );
-    if( reply != KMessageBox::Yes )
+    int reply = KMessageBox::warningContinueCancel( parent, msg, title, i18n("Overwrite") );
+    if( reply != KMessageBox::Continue )
     {
       return( false );
     }
