@@ -24,6 +24,7 @@
 #include <kapplication.h>
 #include <qfont.h> 
 #include <qpalette.h>
+#include <kglobalsettings.h>
 
 
 class SDisplayLine
@@ -428,10 +429,7 @@ class SDisplayFontInfo
 
     SDisplayFontInfo &init( void )
     {
-      font.setFamily( "courier" );
-      font.setPointSize( 12 );
-      font.setWeight( QFont::Bold );
-      font.setItalic( false );
+      font = KGlobalSettings::fixedFont();
       nonPrintChar = '.';
       return( *this );
     }
@@ -446,10 +444,7 @@ class SDisplayFont
     SDisplayFont( void )
     {
       useSystemFont = false;
-      localFont.setFamily( "courier" );
-      localFont.setPointSize( 12 );
-      localFont.setWeight( QFont::Bold );
-      localFont.setItalic( false );
+      localFont = KGlobalSettings::fixedFont();
       nonPrintChar = '.';
     }
 
