@@ -29,6 +29,7 @@
 #include <qlabel.h>
 #include <qradiobutton.h>
 #include <qspinbox.h>
+#include <qwhatsthis.h>
 
 #include <kcolordialog.h>
 #include <kcolordrag.h>
@@ -450,6 +451,10 @@ void COptionDialog::setupFilePage( void )
 
   text = i18n("&Jump to previous cursor position on startup");
   mFile.gotoOffsetCheck = new QCheckBox( text, page );
+  // ### TODO: this is currently not available.
+  mFile.gotoOffsetCheck->setChecked( false );
+  mFile.gotoOffsetCheck->setEnabled( false );
+  // ### END
   topLayout->addWidget( mFile.gotoOffsetCheck, 0, AlignLeft );
   connect( mFile.gotoOffsetCheck, SIGNAL(toggled(bool)),
     this, SLOT( slotChanged()));
@@ -483,12 +488,21 @@ void COptionDialog::setupFilePage( void )
   text = i18n("Don't &save \"Recent\" document list on exit");
   mFile.discardRecentCheck = new QCheckBox( text, page );
   topLayout->addWidget( mFile.discardRecentCheck, 0, AlignLeft );
+  QWhatsThis::add( mFile.discardRecentCheck,
+                   i18n( "Clicking this check box makes KHexEdit forget his recent document list "
+                          "when the program is closed.\n"
+                          "Note: it will not erase any document of the recent document list "
+                          "created by KDE." ) );
   connect( mFile.discardRecentCheck, SIGNAL(toggled(bool)),
     this, SLOT( slotChanged()));
 
   text = i18n("Cl&ear \"Recent\" Document List");
   QPushButton *discardRecentButton = new QPushButton( page );
   discardRecentButton->setText( text );
+  QWhatsThis::add( discardRecentButton,
+                   i18n( "Clicking this button makes KHexEdit forget his recent document list.\n"
+                          "Note: it will not erase any document of the recent document list "
+                          "created by KDE." ) );
   topLayout->addWidget( discardRecentButton, 0, AlignCenter );
   connect( discardRecentButton, SIGNAL(clicked()),
 	   SIGNAL(removeRecentFiles()) );
