@@ -61,16 +61,23 @@ ApmConfig::ApmConfig (QWidget * parent, const char *name)
     QVBoxLayout *top_layout = new QVBoxLayout( this, KDialog::marginHint(),
 					       KDialog::spacingHint() );
 
-    top_layout->addWidget( new QLabel( i18n("This panel lets you configure your APM system and lets\n"
-				    	    "you have access to some of the extra features provided by it"), this) );
-    top_layout->addWidget( new QLabel( i18n("NOTE: some APM implementations have buggy suspend/standby\n"
-				    	    "implementations. You should test these features very gingerly - save\n"
-					    "all your work, check them on and try a suspend/standby from\n"
-					    "the popup menu on the battery icon in the panel if it fails to come\n"
-					    "back successfully uncheck the box again.\n"), this));
+    QLabel *tmp_label = new QLabel( i18n("This panel lets you configure your APM system and lets "
+					"you have access to some of the extra features provided by it"), this );
+    tmp_label->setAlignment( Qt::WordBreak );
+    top_layout->addWidget( tmp_label );
+    
+    tmp_label = new QLabel( i18n("NOTE: some APM implementations have buggy suspend/standby "
+				"implementations. You should test these features very gingerly - save "
+				"all your work, check them on and try a suspend/standby from "
+				"the popup menu on the battery icon in the panel if it fails to come "
+				"back successfully uncheck the box again."), this );
+    tmp_label->setAlignment( Qt::WordBreak );
+    top_layout->addWidget( tmp_label );
 
-    top_layout->addWidget( new QLabel( i18n("Some changes made on this page may require you to quit the laptop panel\n"
-				    	    "and start it again to take effect"), this));
+    tmp_label = new QLabel( i18n("Some changes made on this page may require you to quit the laptop panel "
+				"and start it again to take effect"), this );
+    tmp_label->setAlignment( Qt::WordBreak );
+    top_layout->addWidget( tmp_label );
 
     bool can_enable = laptop_portable::has_apm(1);	// is helper ready
     enableStandby = new QCheckBox( i18n("Enable standby"), this );
@@ -88,12 +95,14 @@ ApmConfig::ApmConfig (QWidget * parent, const char *name)
     if (::access(apm_name, F_OK) != 0 && ::access("/usr/sbin/apm", F_OK) == 0) 
 	    apm_name = "/usr/sbin/apm";
 
-    top_layout->addWidget(new QLabel(i18n("If the above boxes are disabled then there is no 'helper'\n"
-				          "application set up to help change APM states, there are two\n"
-					  "ways you can enable this application, either make the file \n"
-					  "/proc/apm writeable by anyone every time your system boots \n"
-					  "or use the button below to make the %1 application\n"
-					  "set-uid root").arg(apm_name), this));
+    tmp_label = new QLabel(i18n("If the above boxes are disabled then there is no 'helper' "
+				"application set up to help change APM states, there are two "
+				"ways you can enable this application, either make the file "
+				"/proc/apm writeable by anyone every time your system boots "
+				"or use the button below to make the %1 application "
+				"set-uid root").arg(apm_name), this );
+    tmp_label->setAlignment( Qt::WordBreak );
+    top_layout->addWidget( tmp_label );
     QHBoxLayout *ll = new QHBoxLayout(top_layout);
     QPushButton *setupButton = new QPushButton(i18n("Setup Helper Application"), this);
     connect( setupButton, SIGNAL(clicked()), this, SLOT(setupHelper()) );
@@ -102,19 +111,23 @@ ApmConfig::ApmConfig (QWidget * parent, const char *name)
     ll->addWidget(setupButton);
     ll->addStretch(8);
     if (laptop_portable::has_software_suspend()) {
-    	top_layout->addWidget( new QLabel( i18n("Your system seems to have 'Software Suspend' installed, this can\n"
-				    	    "be used to hibernate or 'suspend to disk' your system if you want\n"
-					    "to use this for hibernation check the box below"), this) );
+	tmp_label = new QLabel( i18n("Your system seems to have 'Software Suspend' installed, this can "
+				"be used to hibernate or 'suspend to disk' your system if you want "
+				"to use this for hibernation check the box below"), this );
+	tmp_label->setAlignment( Qt::WordBreak );
+	top_layout->addWidget( tmp_label );
      	enableSoftwareSuspendHibernate = new QCheckBox( i18n("Enable software suspend for hibernate"), this );
     	top_layout->addWidget( enableSoftwareSuspendHibernate );
     	QToolTip::add( enableSoftwareSuspendHibernate, i18n( "If checked this box enables transitions to the 'hibernate' state using the 'Software Suspend' mechanism" ) );
     	enableSoftwareSuspendHibernate->setEnabled(laptop_portable::has_software_suspend(2));
     	connect( enableSoftwareSuspendHibernate, SIGNAL(clicked()), this, SLOT(configChanged()) );
-    	top_layout->addWidget( new QLabel( i18n("If the above box is disabled then you need to be logged in\n"
-				    	    "as root or need a helper application to invoke the Software\n"
-					    "Suspend utility - KDE provides a utility to do this, if you\n"
-					    "wish to use it you must make it set-uid root, the button\n"
-					    "below will do this for you"), this) );
+	tmp_label = new QLabel( i18n("If the above box is disabled then you need to be logged in "
+				"as root or need a helper application to invoke the Software "
+				"Suspend utility - KDE provides a utility to do this, if you "
+				"wish to use it you must make it set-uid root, the button "
+				"below will do this for you"), this );
+	tmp_label->setAlignment( Qt::WordBreak );
+	top_layout->addWidget( tmp_label );
         ll = new QHBoxLayout(this);
         QPushButton *setupSSButton = new QPushButton(i18n("Setup SS Helper Application"), this);
         connect( setupSSButton, SIGNAL(clicked()), this, SLOT(setupHelper2()) );
@@ -178,8 +191,8 @@ void ApmConfig::setupHelper2()	// we use the acpi helper to do software suspend
 		QString str(i18n("The %1 application does not seem to have "
 					"the same size or checksum as when it was compiled we do NOT recommend "
 					"you proceed with making it setuid-root without further investigation").arg(helper));
-		int rc = KMessageBox::questionYesNo(0, str, i18n("KLaptopDaemon"), KStdGuiItem::cancel(), KStdGuiItem::cont(), "");
-		if (rc != KMessageBox::No) 
+		int rc = KMessageBox::warningContinueCancel(0, str, i18n("KLaptopDaemon"), i18n("Run Nevertheless"));
+		if (rc != KMessageBox::Continue) 
 			return;
 	}
 
@@ -253,7 +266,7 @@ void ApmConfig::defaults()
         if (enableSoftwareSuspendHibernate)
 		enableSoftwareSuspendHibernate->setChecked(enablesoftwaresuspend);
 
-        changed(false);
+        changed(true);
 }
 
 
