@@ -74,26 +74,49 @@ WarningConfig::WarningConfig (int t, QWidget * parent, const char *name)
 
     int curRow = 0;
     // setup the trigger stuff:
-    QLabel* low_label;
-    if (type)
-      low_label = new QLabel( i18n("Critical &trigger:"), this );
-    else
-      low_label = new QLabel( i18n("Low &trigger:"), this );
-    grid->addWidget(low_label, curRow, 0);
+    if (type) { 
+        checkCriticalTime = new QCheckBox( i18n("Critical &trigger:"), this );
+        checkCriticalPercent = new QCheckBox( i18n("Critical &trigger:"), this );
+        editCriticalTime = new QSpinBox(1, 60*24, 1, this);
+        editCriticalTime->setSuffix(i18n("keep short, unit in spinbox", "min"));
+        QToolTip::add(editCriticalTime, i18n("When this amount of battery life is left the actions below will be triggered"));
+        editCriticalPercent = new QSpinBox(1, 100, 1, this);
+        editCriticalPercent->setSuffix(i18n("keep short, unit in spinbox", "%"));
+        QToolTip::add(editCriticalPercent, i18n("When this amount of battery life is left the actions below will be triggered"));
+        grid->addWidget(checkCriticalTime, curRow, 0);
+        grid->addWidget(editCriticalTime, curRow++, Qt::AlignLeft);
+        grid->addWidget(checkCriticalPercent, curRow, 0);
+        grid->addWidget(editCriticalPercent, curRow++, Qt::AlignLeft);
 
-    if ( have_time ) {
-      editLow = new QSpinBox( 1, 60*24 /*1 day*/, 1, this ); // min,max,step
-      editLow->setSuffix( i18n("keep short, unit in spinbox", "min") );
-      QToolTip::add( editLow, i18n( "When this amount of battery life is left the actions enabled below will be triggered" ) );
+        connect(editCriticalTime, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+        connect(editCriticalPercent, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+        connect(checkCriticalTime, SIGNAL(toggled(bool)), this, SLOT(configChanged()));
+        connect(checkCriticalPercent, SIGNAL(toggled(bool)), this, SLOT(configChanged()));
+        connect(checkCriticalTime, SIGNAL(toggled(bool)), this, SLOT(checkCriticalTimeChanged(bool)));
+        connect(checkCriticalPercent, SIGNAL(toggled(bool)), this, SLOT(checkCriticalPercentChanged(bool)));
     } else {
-      editLow = new QSpinBox( 1, 100, 1, this ); // min,max.step
-      editLow->setSuffix( i18n("keep short, unit in spinbox", "%") );
-      QToolTip::add( editLow, i18n( "When this amount of battery is left the actions enabled below will be triggered" ) );
+        checkLowTime = new QCheckBox( i18n("Low &trigger:"), this );
+        checkLowPercent = new QCheckBox( i18n("Low &trigger:"), this );        
+        editLowTime = new QSpinBox(1, 60*24, 1, this);
+        editLowTime->setSuffix(i18n("keep short, unit in spinbox", "min"));
+        QToolTip::add(editLowTime, i18n("When this amount of battery life is left the actions below will be triggered"));
+        editLowPercent = new QSpinBox(1, 100, 1, this);
+        editLowPercent->setSuffix(i18n("keep short, unit in spinbox", "%"));
+        QToolTip::add(editLowPercent, i18n("When this amount of battery life is left the actions below will be triggered"));
+        grid->addWidget(checkLowTime, curRow, 0);
+        grid->addWidget(editLowTime, curRow++, Qt::AlignLeft);
+        grid->addWidget(checkLowPercent, curRow, 0);
+        grid->addWidget(editLowPercent, curRow++, Qt::AlignLeft);
+        
+        connect(editLowTime, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+        connect(editLowPercent, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+        connect(checkLowTime, SIGNAL(toggled(bool)), this, SLOT(configChanged()));
+        connect(checkLowPercent, SIGNAL(toggled(bool)), this, SLOT(configChanged()));
+        connect(checkLowTime, SIGNAL(toggled(bool)), this, SLOT(checkLowTimeChanged(bool)));
+        connect(checkLowPercent, SIGNAL(toggled(bool)), this, SLOT(checkLowPercentChanged(bool)));
     }
-    low_label->setBuddy( editLow );
-    grid->addWidget( editLow, curRow++, 1, Qt::AlignLeft );
-    connect(editLow, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
 
+    
     // setup the Run Command stuff
     checkRunCommand = new QCheckBox(i18n("Run &command:"), this);
     grid->addWidget(checkRunCommand, curRow, 0);
@@ -249,19 +272,18 @@ WarningConfig::WarningConfig (int t, QWidget * parent, const char *name)
 
     QLabel* explain;
     if (type) {
-      explain = new QLabel(i18n("This panel controls how and when you receive warnings\nthat your battery power is going to run out VERY VERY soon."), this);
+      explain = new QLabel(i18n("This panel controls how and when you receive warnings that your battery power is going to run out VERY VERY soon."), this);
     } else {
-      explain = new QLabel(i18n("This panel controls how and when you receive warnings\nthat your battery power is about to run out"), this);
+      explain = new QLabel(i18n("This panel controls how and when you receive warnings that your battery power is about to run out"), this);
     }
-    grid->addMultiCellWidget(explain, curRow, curRow, 0, 1,
-			     Qt::AlignLeft|Qt::AlignTop);
+    explain->setAlignment( Qt::WordBreak );
+    grid->addMultiCellWidget(explain, curRow, curRow, 0, 1);
     ++curRow;
 
     if (!can_suspend && !can_standby && !can_hibernate) {
       // display help text:
       QLabel* note = laptop_portable::how_to_do_suspend_resume(this);
-      grid->addMultiCellWidget(note, curRow, curRow, 0, 1,
-			       Qt::AlignLeft|Qt::AlignTop);
+      grid->addMultiCellWidget(note, curRow, curRow, 0, 1);
       ++curRow;
     }
     grid->setRowStretch(curRow++, 1);
@@ -296,6 +318,30 @@ void WarningConfig::performance_changed(bool v)
   configChanged();
 }
 
+void WarningConfig::checkLowTimeChanged(bool state)
+{
+  checkLowPercent->setChecked(state ? false : true);
+  editLowPercent->setEnabled(state ? false : true);
+}
+
+void WarningConfig::checkLowPercentChanged(bool state)
+{
+  checkLowTime->setChecked(state ? false : true);
+  editLowTime->setEnabled(state ? false : true);
+}
+
+void WarningConfig::checkCriticalTimeChanged(bool state)
+{
+  checkCriticalPercent->setChecked(state ? false : true);
+  editCriticalPercent->setEnabled(state ? false : true);
+}
+
+void WarningConfig::checkCriticalPercentChanged(bool state)
+{
+  checkCriticalTime->setChecked(state ? false: true);
+  editCriticalTime->setEnabled(state ? false : true);
+}
+
 
 void WarningConfig::save()
 {
@@ -316,12 +362,29 @@ void WarningConfig::save()
     	do_throttle = (throttle? throttle->isChecked() : false);
     	val_throttle = (throttle_val? throttle_val->currentText() : "");
     	runcommand_val = editRunCommand->url();
-    	low_val = editLow->value();
+        if (type) {
+          time_based_action_critical = checkCriticalTime->isChecked();
+          critical_val_time = editCriticalTime->value();
+          critical_val_percent = editCriticalPercent->value();
+        } else {
+          time_based_action_low = checkLowTime->isChecked();
+          low_val_time = editLowTime->value();
+          low_val_percent = editLowPercent->value();
+        }
+        
     	sound_val = editPlaySound->url();
     }
     config->setGroup((type?"BatteryCritical":"BatteryLow"));
-       
-    config->writeEntry("LowVal", low_val);
+
+    if (config->group() == "BatteryLow") {
+        config->writeEntry("TimeBasedAction", time_based_action_low);
+        config->writeEntry("LowValTime", low_val_time);
+        config->writeEntry("LowValPercent", low_val_percent);
+    } else {
+        config->writeEntry("TimeBasedAction", time_based_action_critical);
+        config->writeEntry("CriticalValTime", critical_val_time);
+        config->writeEntry("CriticalValPercent", critical_val_percent);
+    }
     config->writeEntry("RunCommand", runcommand);
     config->writeEntry("PlaySound", playsound);
     config->writeEntry("Logout", logout);
@@ -358,7 +421,15 @@ void WarningConfig::my_load(int x)
 	if (!x) {
 		config->setGroup((type?"BatteryCritical":"BatteryLow"));
 
-		low_val = config->readNumEntry("LowVal", (type? 5:15));
+                if (config->group() == "BatteryLow") {
+                    time_based_action_low = config->readBoolEntry("TimeBasedAction", true);
+                    low_val_time = config->readNumEntry("LowValTime", 15);
+                    low_val_percent = config->readNumEntry("LowValPercent", 7);
+                } else {
+                    time_based_action_critical = config->readBoolEntry("TimeBasedAction", true);
+                    critical_val_time = config->readNumEntry("CriticalValTime", 5);
+                    critical_val_percent = config->readNumEntry("CriticalValPercent", 3);
+                }
 		runcommand = config->readBoolEntry("RunCommand", false);
 		playsound = config->readBoolEntry("PlaySound", false);
 		logout = config->readBoolEntry("Logout", false);
@@ -436,8 +507,20 @@ void WarningConfig::my_load(int x)
 		}
 		checkNone->setChecked(!do_suspend&!do_standby&!do_hibernate&!logout&!shutdown);
 		editRunCommand->setURL(runcommand_val);
-		editLow->setValue(low_val);
-		editPlaySound->setURL(sound_val);
+
+                if(type) {
+                checkCriticalTime->setChecked(time_based_action_critical ? true : false);
+                editCriticalTime->setValue(critical_val_time);
+                checkCriticalPercent->setChecked(time_based_action_critical ? false : true);
+                editCriticalPercent->setValue(critical_val_percent);
+                } else {
+                  checkLowTime->setChecked(time_based_action_low ? true : false);
+                  editLowTime->setValue(low_val_time);
+                  checkLowPercent->setChecked(time_based_action_low ? false : true);
+                  editLowPercent->setValue(low_val_percent);
+                }
+                
+                editPlaySound->setURL(sound_val);
 	}
 	changed(false);
 
@@ -462,9 +545,13 @@ void WarningConfig::defaults()
 	val_throttle = "";
 	do_suspend = (type && checkSuspend);
 	runcommand_val = "";
-	low_val = (type?5:15);
-	sound_val = "";
-	
+        time_based_action_low = true;
+        time_based_action_critical = true;
+        low_val_time = 15;
+        low_val_percent = 7;
+        critical_val_time = 5;
+        critical_val_percent = 3;
+        sound_val = "";
 
 	if (apm) {
 		checkRunCommand->setChecked(runcommand);
@@ -508,10 +595,13 @@ void WarningConfig::defaults()
 		}
 		checkNone->setChecked(!do_suspend&!do_standby&!do_hibernate&!logout&!shutdown);
 		editRunCommand->setURL(runcommand_val);
-		editLow->setValue(low_val);
+		editLowTime->setValue(low_val_time);
+                editLowPercent->setValue(low_val_percent);
+                editCriticalTime->setValue(critical_val_time);
+                editCriticalPercent->setValue(critical_val_percent);
 		editPlaySound->setURL(sound_val);
 	}
-	changed(false);
+	changed(true);
 }
 
 
