@@ -55,6 +55,10 @@ private slots:
   void brightness_changed(bool v);
   void throttle_changed(bool v);
   void performance_changed(bool v);
+  void checkLowTimeChanged(bool state);
+  void checkLowPercentChanged(bool state);
+  void checkCriticalTimeChanged(bool state);
+  void checkCriticalPercentChanged(bool state);
     
 private:
   void my_load(int x);
@@ -63,7 +67,14 @@ private:
  
   KURLRequester* editRunCommand;
   KURLRequester* editPlaySound;
-  QSpinBox* editLow;
+  QCheckBox* checkLowTime;
+  QCheckBox* checkLowPercent;
+  QCheckBox* checkCriticalTime;
+  QCheckBox* checkCriticalPercent;
+  QSpinBox* editLowTime;
+  QSpinBox* editLowPercent;
+  QSpinBox* editCriticalTime;
+  QSpinBox* editCriticalPercent;
  
   QCheckBox *checkRunCommand;
   QCheckBox *checkPlaySound;
@@ -82,10 +93,11 @@ private:
  
   bool    apm, runcommand, playsound, beep, notify, do_suspend, do_standby, do_hibernate, logout, shutdown, do_brightness;
   bool	  do_performance, do_throttle;
+  bool    time_based_action_low, time_based_action_critical;
   QString val_performance, val_throttle;
   int 	  val_brightness;
   QString runcommand_val, sound_val;
-  int     low_val;
+  int     low_val_time, low_val_percent, critical_val_time, critical_val_percent;
   int     have_time, type;
 };
 
