@@ -65,7 +65,12 @@ PowerBookMonitor::~PowerBookMonitor()
 
 bool PowerBookMonitor::init()
 {
+// pbbuttons 0.6.7 or newer
+#ifdef CLIENT_REGISTER
+	return ( ipc_init( "kmilo", LIBMODE_CLIENT, CLIENT_REGISTER ) == 0 );
+#else
 	return ( ipc_init( LIBMODE_CLIENT, 1 ) == 0 );
+#endif
 }
 
 
@@ -105,9 +110,6 @@ Monitor::DisplayType PowerBookMonitor::poll()
 	if ( m_sleep ) {
 		rc = Monitor::Sleep;
 	}
-	if ( tag && tag->tag == TAG_END &&
-			 (tag->tag & FLG_ERROR) )
-		rc = Monitor::Error;
 
 	return rc;
 }
@@ -159,5 +161,5 @@ struct tagitem* PowerBookMonitor::readMessage()
 
 }
 
-K_EXPORT_COMPONENT_FACTORY(kmilo_powerbook, KGenericFactory<PowerBookMonitor>("kmilo_powerbook"))
+K_EXPORT_COMPONENT_FACTORY(kmilo_powerbook, KGenericFactory<KMilo::PowerBookMonitor>("kmilo_powerbook"))
 
