@@ -33,7 +33,4 @@ void KCMThinkpadGeneral::slotChanged() {
 }
 
 
-void KCMThinkpadGeneral::commandExec_urlSelected( const QString & )
-{
-    emit(changed());
-}
+
