@@ -135,22 +135,23 @@ void KSim::Sysinfo::sysUpdate()
     QString memory = m_config->memoryFormat();
     unsigned long total = system.totalRam();
     unsigned long free = system.freeRam();
-    unsigned long shared = system.sharedRam();
-    unsigned long buffer = system.bufferRam();
-    unsigned long cache = system.cacheRam();
-    unsigned long used = system.usedRam();
-    unsigned long allFree = free + buffer + cache;
+  unsigned long shared = system.sharedRam();
+  unsigned long buffer = system.bufferRam();
+  unsigned long cache = system.cacheRam();
+  unsigned long used = system.usedRam();
+  unsigned long allFree = free + buffer + cache;
+  bool all = memory.find( "%F" ) != -1;
 
-    bool all = memory.find( "%F" ) != -1;
-
-    memory.replace(QRegExp("%s"), QString::number(System::bytesToMegs(shared)));
-    memory.replace(QRegExp("%b"), QString::number(System::bytesToMegs(buffer)));
-    memory.replace(QRegExp("%c"), QString::number(System::bytesToMegs(cache)));
-    memory.replace(QRegExp("%u"), QString::number(System::bytesToMegs(used)));
-    memory.replace(QRegExp("%t"), QString::number(System::bytesToMegs(total)));
-    memory.replace(QRegExp("%f"), QString::number(System::bytesToMegs(free)));
-    memory.replace(QRegExp("%F"), QString::number(System::bytesToMegs(allFree)));
-    m_memLabel->setText(memory);
+  memory.replace(QRegExp("%s"), QString::number(System::bytesToMegs(shared)));
+  memory.replace(QRegExp("%b"), QString::number(System::bytesToMegs(buffer)));
+  memory.replace(QRegExp("%c"), QString::number(System::bytesToMegs(cache)));
+  memory.replace(QRegExp("%u"), QString::number(System::bytesToMegs(used)));
+  memory.replace(QRegExp("%t"), QString::number(System::bytesToMegs(total)));
+  memory.replace(QRegExp("%f"), QString::number(System::bytesToMegs(free)));
+  memory.replace(QRegExp("%F"), QString::number(System::bytesToMegs(allFree)));
+    kdDebug(2003) << memory << endl;
+    m_memLabel->setText("Memory");
+    QToolTip::add(m_memLabel, memory );
 
     if ( !all )
       m_memLabel->setValue( System::bytesToMegs( total ) - System::bytesToMegs( free ) );
@@ -166,7 +167,8 @@ void KSim::Sysinfo::sysUpdate()
     swap.replace(QRegExp("%u"), QString::number(System::bytesToMegs(swapUsed)));
     swap.replace(QRegExp("%t"), QString::number(System::bytesToMegs(total)));
     swap.replace(QRegExp("%f"), QString::number(System::bytesToMegs(free)));
-    m_swapLabel->setText(swap);
+    m_swapLabel->setText("Swap");
+    QToolTip::add(m_swapLabel, swap);
     m_swapLabel->setValue(System::bytesToMegs(total) - System::bytesToMegs(free));
   }
 
@@ -192,7 +194,7 @@ void KSim::Sysinfo::createView()
       m_timeLabel = new KSim::Label(this);
       m_layout->insertWidget(timeLocation - offset, m_timeLabel);
     }
-    QToolTip::add(m_timeLabel, i18n("Time of the pc"));
+    QToolTip::add(m_timeLabel, i18n("Current system time"));
     m_timeLabel->show();
   }
   else {
@@ -222,7 +224,7 @@ void KSim::Sysinfo::createView()
       m_uptimeLabel = new KSim::Label(KSim::Types::Uptime, this);
       m_layout->insertWidget(uptimeLocation - offset, m_uptimeLabel);
     }
-    QToolTip::add(m_uptimeLabel, i18n("Uptime of the system"));
+    QToolTip::add(m_uptimeLabel, i18n("System uptime"));
     m_uptimeLabel->show();
   }
   else {
@@ -237,7 +239,7 @@ void KSim::Sysinfo::createView()
           KSim::Types::Mem, this);
       m_layout->insertWidget(memLocation - offset, m_memLabel);
     }
-    QToolTip::add(m_memLabel, i18n("Total memory - Free memory"));
+    
     m_memLabel->show();
   }
   else {
@@ -252,7 +254,6 @@ void KSim::Sysinfo::createView()
           KSim::Types::Swap, this);
       m_layout->insertWidget(swapLocation - offset, m_swapLabel);
     }
-    QToolTip::add(m_swapLabel, i18n("Total swap - Free swap"));
     m_swapLabel->show();
   }
   else {
